==> unv.utils-0.1.tar.gz: unv.utils-0.1/README.md <==
# UNV Utils - provides basic helpers for other packages

[![Build Status](https://readthedocs.org/projects/unv_utils/badge/?version=latest&style=flat)](https://readthedocs.org/projects/unv_utils)
[![Docs Build Status](https://travis-ci.org/c137digital/unv_utils.svg?branch=master)](https://travis-ci.org/c137digital/unv_utils)
[![Maintainability](https://api.codeclimate.com/v1/badges/97fab716c44dfd18aa79/maintainability)](https://codeclimate.com/github/c137digital/unv_utils/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/97fab716c44dfd18aa79/test_coverage)](https://codeclimate.com/github/c137digital/unv_utils/test_coverage)
[![Requirements Status](https://requires.io/github/c137digital/unv_utils/requirements.svg?branch=master)](https://requires.io/github/c137digital/unv_utils/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI license](https://img.shields.io/pypi/l/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI version fury.io](https://badge.fury.io/py/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI download month](https://img.shields.io/pypi/dm/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)

## What you need to change

- package name to whatever you want
- setup.py
  - name
  - description
  - author (git)
  - email (git)
  - install_requires + requirements.txt
  - LICENSE

==> unv.utils-0.3.tar.gz: unv.utils-0.3/README.md <==
# UNV Utils - provides basic helpers for other packages

[![Build Status](https://readthedocs.org/projects/unv_utils/badge/?version=latest&style=flat)](https://readthedocs.org/projects/unv_utils)
[![Docs Build Status](https://travis-ci.org/c137digital/unv_utils.svg?branch=master)](https://travis-ci.org/c137digital/unv_utils)
[![Maintainability](https://api.codeclimate.com/v1/badges/97fab716c44dfd18aa79/maintainability)](https://codeclimate.com/github/c137digital/unv_utils/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/97fab716c44dfd18aa79/test_coverage)](https://codeclimate.com/github/c137digital/unv_utils/test_coverage)
[![Requirements Status](https://requires.io/github/c137digital/unv_utils/requirements.svg?branch=master)](https://requires.io/github/c137digital/unv_utils/requirements/?branch=master)
[![PyPI implementation](https://img.shields.io/pypi/implementation/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI license](https://img.shields.io/pypi/l/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)
[![PyPI version fury.io](https://badge.fury.io/py/unv.utils.svg)](https://pypi.python.org/pypi/unv.utils/)
[![PyPI download month](https://img.shields.io/pypi/dm/unv_utils.svg)](https://pypi.python.org/pypi/unv_utils/)

## What you need to change

- package name to whatever you want
- setup.py
  - name
  - description
  - author (git)
  - email (git)
  - install_requires + requirements.txt
  - LICENSE
